@@ -6,13 +6,16 @@ package Business::Tax::VAT::Validation;
 =cut
 
  ############################################################################
+# Original author:                                                           #
 # IT Development software                                                    #
 # European VAT number validator Version 1.0.2                                #
-# Copyright 2003 Nauwelaerts B  bpgn@cpan.org                                #
 # Created 06/08/2003            Last Modified 30/11/2012                     #
+#                                                                            #
+# Maintainership kindly handed over to David Precious (BIGPRESH) in 2015     #
  ############################################################################
 # COPYRIGHT NOTICE                                                           #
 # Copyright 2003 Bernard Nauwelaerts  All Rights Reserved.                   #
+# Copyright 2015 David Precious       All Rights Reserved.                   #
 #                                                                            #
 # THIS SOFTWARE IS RELEASED UNDER THE GNU Public Licence                     #
 # Please see COPYING for details                                             #
@@ -22,80 +25,18 @@ package Business::Tax::VAT::Validation;
 #  WITHOUT ANY WARRANTY, without even the implied warranty of                #
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                      #
 #                                                                            #
- ############################################################################
-# Revision history (dd/mm/yyyy) :                                            #
-#                                                                            #
-# 1.02   30/11/2012; Fix POD typo; Thanks to Gregor Herrmann                 #
-# 1.01   28/11/2012; Fix POD UTF8 Issue; Thanks to Graham Knop               #
-# 1.00   25/03/2012; This module now uses the VIES SOAP interface.           #
-#                    Add get_informations method                             #
-# 0.24   06/03/2012; Fix traderName field required for EL and ES MS          #
-#                    Update POST request fields                              #
-# 0.23   29/02/2012; Fix regexp in _is_res_ok with multiline regexp          #
-#                    (Thanks to Bart Heupers)                                #
-# 0.22   04/10/2011; Typo fix in POD error message #2                        #
-#                    (Thanks to Martin H. Sluka)                             #
-#                    Minor POD fixes (BPGN)                                  #
-#                    Fix subs args bug (performance fix) (BPGN)              #
-# 0.21   04/08/2009; New error status 19: EU database too busy               #
-#                    (Martin H. Sluka)                                       #
-# 0.20   18/08/2008; VIES HTML changes: now allowing multiples spaces        #
-#                    (Thanks to Simon Williams, Benoît Galy & Raluca Boboia) #
-# 0.19   29/04/2008; HU regexp: missing digit "9" added                      #
-#                    (Thanks to Simon Williams)                              #
-# 0.18   03/01/2008; BE regexp: from transitional 9-digit & 10-digit format  #
-#                    to 10-digit new format                                  #
-# 0.16   13/07/2007; Allowing spaces in regexps                              #
-# 0.15   06/07/2007; Added missing "keys" during $self->{members}            #
-#                    constuction                                             #
-#                    (Thanks to Dave O.)                                     #
-#                    Corrected returned 0-1 error codes inversion            #
-#                    Some POD improvements                                   #
-# 0.14   05/07/2007; VIES interface changed $baseurl, and POST params were   #
-#                    changed to lowercase. Added support for Bulgaria and    #
-#                    Romania (thanks to Kaloyan Iliev)                       #
-#                    New get_last_error_code method                          #
-#                    Updated regexps according to the actual VIES FAQ        #
-#                    Some slight documentation improvements                  #
-#                    Improved tests: each regexp is tested accordind to FAQ  #
-# 0.13   16/01/2007; VIES interface changed "not found" layout               #
-#                    (Thanks to Tom Kirkpatrick for this update)             #
-# 0.12   10/11/2006; YAML Compliance                                         #
-# 0.11   10/11/2006; Minor bug allowing one forbidden character              #
-#                    corrected in Belgian regexp                             #
-#                     (Thanks to Andy Wardley for this report)               #
-#                    + added regular_expressions property                    #
-#                      for external testing purposes                         #
-# 0.10   20/07/2006; Adding Test::Pod to test suite                          #
-# 0.09   20/06/2006; local_check method allows you to test VAT numbers       #
-#                    without asking the EU database. Based on regexps.       #
-# 0.08   20/06/2006; 9 and 10 digits transitional regexp for Belgium         #
-#                    From 31/12/2007, only 10 digits will be valid           #
-# 0.07   25/05/2006; Now we use "request" method not "simple request"        #
-#                    in order to follow potential redirects                  #
-# 0.06   25/05/2006; Changed $baseurl                                        #
-#                    (Thanks to Torsten Mueller for this update)             #
-# 0.05   19/01/2006; Adding support for proxy settings                       #
-#                    (Thanks to Tom Kirkpatrick for this update)             #
-# 0.04   01/11/2004; Adding support for error "Member Service Unavailable"   #
-# 0.03   01/11/2004; Adding 10 new members.                                  #
-#                    (Thanks to Robert Alloway for this update)              #
-# 0.02   29/09/2003; Fix alphanumeric VAT numbers rejection                  #
-#                    (Thanks to Robert Alloway for the regexps)              #
-# 0.01   06/08/2003; Initial release                                         #
-#                                                                            #
- ############################################################################
+############################################################################
 use strict;
 
 BEGIN {
-    $Business::Tax::VAT::Validation::VERSION = '1.02';
+    $Business::Tax::VAT::Validation::VERSION = '1.12';
     use HTTP::Request::Common qw(POST);
     use LWP::UserAgent;
 }
 
 =head1 NAME
 
-Business::Tax::VAT::Validation - A class for european VAT numbers validation.
+Business::Tax::VAT::Validation - Validate EU VAT numbers against VIES
 
 =head1 SYNOPSIS
 
@@ -112,9 +53,13 @@ Business::Tax::VAT::Validation - A class for european VAT numbers validation.
   
 =head1 DESCRIPTION
 
-This class provides an easy api to check european VAT numbers' syntax, and if they has been registered by the competent authorities.
+This class provides an easy API to check European VAT numbers' syntax,
+and if they has been registered by the competent authorities.
 
-It asks the EU database (VIES) for this, using its SOAP interface methods. 
+It asks the EU database (VIES) for this, using its SOAP API.  Basic checks that
+the supplied VAT number fit the expected format for the specified EU member
+state are performed first, to avoid unnecessarily sending queries to VIES for
+input that could never be valid.
 
 
 =head1 CONSTRUCTOR
@@ -137,9 +82,10 @@ It asks the EU database (VIES) for this, using its SOAP interface methods.
 sub new {
     my ( $class, %arg ) = @_;
     my $self = {
-        baseurl      => $arg{baseurl} || 'http://ec.europa.eu/taxation_customs/vies/services/checkVatService',
+        baseurl      => $arg{baseurl} || 'https://ec.europa.eu/taxation_customs/vies/services/checkVatService',
         error        => '',
         error_code   => 0,
+        response     => '',
         re           => {
             ### t/01_localcheck.t tests if these regexps accepts all regular VAT numbers, according to VIES FAQ
             AT => 'U[0-9]{8}',
@@ -155,8 +101,9 @@ sub new {
             FI => '[0-9]{8}',
             FR => '[A-Za-z0-9]{2} ?[0-9]{9}',
             GB => '([0-9]{3} ?[0-9]{4} ?[0-9]{2}|[0-9]{3} ?[0-9]{4} ?[0-9]{2} ?[0-9]{3}|GD[0-9]{3}|HA[0-9]{3})',
+            HR => '[0-9]{11}',
             HU => '[0-9]{8}',
-            IE => '[0-9][A-Za-z0-9\+\*][0-9]{5}[A-Za-z]',
+            IE => '[0-9][A-Za-z0-9\+\*][0-9]{5}[A-Za-z]{1,2}',
             IT => '[0-9]{11}',
             LT => '([0-9]{9}|[0-9]{12})',
             LU => '[0-9]{8}',
@@ -364,6 +311,14 @@ sub get_last_error_code {
     $_[0]->{error_code};
 }
 
+=item B<get_last_response> - Returns the full last response
+
+=cut
+
+sub get_last_response {
+    $_[0]->{response};
+}
+
 ### PRIVATE FUNCTIONS ==========================================================
 sub _format_vatn {
     my ( $self, $vatn, $mscc ) = @_;
@@ -404,6 +359,7 @@ sub _is_res_ok {
     my ( $self, $code, $res ) = @_;
     $self->{informations}={};
     $res=~s/[\r\n]/ /g;
+    $self->{response} = $res;
     if ($code == 200) {
         if ($res=~m/<valid> *(.*?) *<\/valid>/) {
             my $v = $1;
@@ -466,7 +422,9 @@ If you find this module useful, or have any comments, suggestions or improvement
 
 =head1 AUTHOR
 
-Bernard Nauwelaerts <bpgn@cpan.org>
+Original author: Bernard Nauwelaerts <bpgn@cpan.org>
+
+Maintainership since 2015: David Precious (BIGPRESH) <davidp@preshweb.co.uk>
 
 
 =head1 CREDITS
